@@ -261,9 +261,19 @@ class DocumentClient(BaseDocumentCloudClient):
         """
         # Required parameters
         if hasattr(pdf, 'read'):
+            try:
+                size = os.fstat(pdf.fileno()).st_size
+            except:
+                size = 0
             params = {'file': pdf}
         else:
+            size = os.path.getsize(pdf)
             params = {'file': open(pdf, 'rb')}
+        # Enforce file size limit of the DocumentCloud API
+        if size >= 399999999:
+            raise ValueError("The pdf you have submited if over the \
+DocumentCloud API's 400MB file size limit. Split it into smaller pieces \
+and try again.")
         # Optional parameters
         if title:
             params['title'] = title
